################
Sphinx-Compendia
################

.. container:: tagline

    A simple API for creating Sphinx_ domains_ and structuring arbitrary
    collections.

.. container:: center

        |docs_badge| |test_badge| |lic_badge| |pypi_badge| |download_badge| |black_badge|

.. |docs_badge| image:: https://gitlab.com/cblegare/sphinx-compendia/badges/main/pipeline.svg?job=pages&key_text=docs
    :target: https://gitlab.com/cblegare/sphinx-compendia/-/pipelines
    :alt: Gitlab - Docs

.. |test_badge| image:: https://gitlab.com/cblegare/sphinx-compendia/badges/main/coverage.svg?job=coverage
    :target: https://gitlab.com/cblegare/sphinx-compendia/-/pipelines
    :alt: Gitlab - Coverage

.. |lic_badge| image:: https://img.shields.io/pypi/l/sphinx-compendia?color=blue
    :target: https://gitlab.com/cblegare/sphinx-compendia/-/blob/main/LICENSE
    :alt: PyPI - License

.. |release_badge| image:: https://gitlab.com/cblegare/sphinx-compendia/-/badges/release.svg
    :target: https://gitlab.com/cblegare/sphinx-compendia/-/releases
    :alt: Gitlab - Release

.. |pypi_badge| image:: https://img.shields.io/pypi/v/sphinx-compendia
    :target: https://pypi.org/project/sphinx-compendia
    :alt: PyPI - Release

.. |download_badge| image:: https://img.shields.io/pypi/dm/sphinx-compendia
    :target: https://pypi.org/project/sphinx-compendia/
    :alt: PyPI - Downloads

.. |black_badge| image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
    :alt: Formatting - Black

**Sphinx-Compendia** is especially useful for documenting **collections**,
**compendiums**, **catalogs**, **inventories**, **compilations**, **digests**
and such.


----


**Sphinx-Compendia** is

- `Hosted on Gitlab <https://gitlab.com/cblegare/sphinx-compendia>`__
- `Mirrored on Github <https://github.com/cblegare/sphinx-compendia>`__
- `Distributed on PyPI <https://pypi.org/project/sphinx-compendia/>`__
- `Documented online <https://cblegare.gitlab.io/sphinx-compendia/>`__

.. _Sphinx: https://www.sphinx-doc.org/en/master/index.html
.. _documentation: https://cblegare.gitlab.io/sphinx-compendia
.. _domains: https://www.sphinx-doc.org/en/master/usage/restructuredtext/domains.html
